@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2018-2021, earthobservations developers.
+# Copyright (C) 2018-2021, earthobservations developers.
 # Distributed under the MIT License. See LICENSE for more info.
 from dataclasses import dataclass
 from datetime import datetime
@@ -93,6 +93,18 @@ class StationsResult(ExportMixin):
     def si_units(self) -> bool:
         return self.stations.si_units
 
+    @property
+    def skip_empty(self) -> bool:
+        return self.stations.skip_empty
+
+    @property
+    def skip_threshold(self) -> float:
+        return self.stations.skip_threshold
+
+    @property
+    def dropna(self) -> float:
+        return self.stations.dropna
+
     @property
     def _has_tidy_data(self) -> bool:
         return self.stations._has_tidy_data
